@@ -1,5 +1,7 @@
 """PGSync views."""
 import logging
+import warnings
+from typing import Callable, List
 
 import sqlalchemy as sa
 from sqlalchemy.dialects.postgresql import array
@@ -32,7 +34,6 @@ class CreateView(DDLElement):
 def compile_create_view(
     element: CreateView, compiler: PGDDLCompiler, **kwargs
 ) -> str:
-
     statement: str = compiler.sql_compiler.process(
         element.selectable,
         literal_binds=True,
@@ -70,6 +71,29 @@ def compile_drop_view(
     )
 
 
+class RefreshView(DDLElement):
+    def __init__(
+        self,
+        schema: str,
+        name: str,
+        concurrently: bool = False,
+    ):
+        self.schema: str = schema
+        self.name: str = name
+        self.concurrently: bool = concurrently
+
+
+@compiler.compiles(RefreshView)
+def compile_refresh_view(
+    element: RefreshView, compiler: PGDDLCompiler, **kwargs
+) -> str:
+    concurrently: str = "CONCURRENTLY" if element.concurrently else ""
+    return (
+        f"REFRESH MATERIALIZED VIEW {concurrently} "
+        f'"{element.schema}"."{element.name}"'
+    )
+
+
 class CreateIndex(DDLElement):
     def __init__(self, name: str, schema: str, view: str, columns: list):
         self.schema: str = schema
@@ -100,12 +124,93 @@ def compile_drop_index(
     return f"DROP INDEX IF EXISTS {element.name}"
 
 
+def _get_constraints(
+    model: Callable,
+    schema: str,
+    tables: List[str],
+    label: str,
+    constraint_type: str,
+) -> sa.sql.Select:
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", category=sa.exc.SAWarning)
+        table_constraints = model("table_constraints", "information_schema")
+        key_column_usage = model("key_column_usage", "information_schema")
+        constraint_column_usage = model(
+            "constraint_column_usage", "information_schema"
+        )
+    return (
+        sa.select(
+            [
+                table_constraints.c.table_name,
+                sa.func.ARRAY_AGG(
+                    sa.cast(
+                        key_column_usage.c.column_name,
+                        sa.TEXT,
+                    )
+                ).label(label),
+            ]
+        )
+        .join(
+            key_column_usage,
+            sa.and_(
+                key_column_usage.c.constraint_name
+                == table_constraints.c.constraint_name,
+                key_column_usage.c.table_schema
+                == table_constraints.c.table_schema,
+                key_column_usage.c.table_schema == schema,
+            ),
+        )
+        # .join(
+        #     constraint_column_usage,
+        #     sa.and_(
+        #         constraint_column_usage.c.constraint_name
+        #         == table_constraints.c.constraint_name,
+        #         constraint_column_usage.c.table_schema
+        #         == table_constraints.c.table_schema,
+        #     ),
+        # )
+        .where(
+            *[
+                table_constraints.c.table_name.in_(tables),
+                table_constraints.c.constraint_type == constraint_type,
+            ]
+        )
+        .group_by(table_constraints.c.table_name)
+    )
+
+
+def _primary_keys(
+    model: Callable, schema: str, tables: List[str]
+) -> sa.sql.Select:
+    return _get_constraints(
+        model,
+        schema,
+        tables,
+        label="primary_keys",
+        constraint_type="PRIMARY KEY",
+    )
+
+
+def _foreign_keys(
+    model: Callable, schema: str, tables: List[str]
+) -> sa.sql.Select:
+    return _get_constraints(
+        model,
+        schema,
+        tables,
+        label="foreign_keys",
+        constraint_type="FOREIGN KEY",
+    )
+
+
 def create_view(
-    engine,
+    engine: sa.engine.Engine,
+    model: Callable,
+    fetchall: Callable,
     schema: str,
     tables: list,
     user_defined_fkey_tables: dict,
-    base: "Base",  # noqa F821
+    views: List[str],
 ) -> None:
     """
     View describing primary_keys and foreign_keys for each table
@@ -128,18 +233,16 @@ def create_view(
     structure  | {id}         | {id}
     """
 
-    views: list = sa.inspect(engine).get_view_names(schema)
-
     rows: dict = {}
     if MATERIALIZED_VIEW in views:
-        for table_name, primary_keys, foreign_keys in base.fetchall(
+        for table_name, primary_keys, foreign_keys in fetchall(
             sa.select(["*"]).select_from(
                 sa.text(f"{schema}.{MATERIALIZED_VIEW}")
             )
         ):
             rows.setdefault(
                 table_name,
-                {"primary_keys": set([]), "foreign_keys": set([])},
+                {"primary_keys": set(), "foreign_keys": set()},
             )
             if primary_keys:
                 rows[table_name]["primary_keys"] = set(primary_keys)
@@ -152,22 +255,18 @@ def create_view(
         for table in set(tables):
             tables.add(f"{schema}.{table}")
 
-    for table_name, columns in base.fetchall(
-        base._primary_keys(schema, tables)
-    ):
+    for table_name, columns in fetchall(_primary_keys(model, schema, tables)):
         rows.setdefault(
             table_name,
-            {"primary_keys": set([]), "foreign_keys": set([])},
+            {"primary_keys": set(), "foreign_keys": set()},
         )
         if columns:
             rows[table_name]["primary_keys"] |= set(columns)
 
-    for table_name, columns in base.fetchall(
-        base._foreign_keys(schema, tables)
-    ):
+    for table_name, columns in fetchall(_foreign_keys(model, schema, tables)):
         rows.setdefault(
             table_name,
-            {"primary_keys": set([]), "foreign_keys": set([])},
+            {"primary_keys": set(), "foreign_keys": set()},
         )
         if columns:
             rows[table_name]["foreign_keys"] |= set(columns)
@@ -176,7 +275,7 @@ def create_view(
         for table_name, columns in user_defined_fkey_tables.items():
             rows.setdefault(
                 table_name,
-                {"primary_keys": set([]), "foreign_keys": set([])},
+                {"primary_keys": set(), "foreign_keys": set()},
             )
             if columns:
                 rows[table_name]["foreign_keys"] |= set(columns)
@@ -184,7 +283,7 @@ def create_view(
     if not rows:
         rows.setdefault(
             None,
-            {"primary_keys": set([]), "foreign_keys": set([])},
+            {"primary_keys": set(), "foreign_keys": set()},
         )
 
     statement = sa.select(
@@ -218,7 +317,29 @@ def create_view(
     logger.debug(f"Created view: {schema}.{MATERIALIZED_VIEW}")
 
 
-def drop_view(engine, schema: str) -> None:
-    logger.debug(f"Dropping view: {schema}.{MATERIALIZED_VIEW}")
-    engine.execute(DropView(schema, MATERIALIZED_VIEW))
-    logger.debug(f"Dropped view: {schema}.{MATERIALIZED_VIEW}")
+def is_view(
+    engine: sa.engine.Engine,
+    schema: str,
+    table: str,
+    materialized: bool = True,
+) -> bool:
+    column: str = "matviewname" if materialized else "viewname"
+    pg_table: str = "pg_matviews" if materialized else "pg_views"
+    with engine.connect() as conn:
+        return (
+            conn.execute(
+                sa.select([sa.column(column)])
+                .select_from(sa.text(pg_table))
+                .where(
+                    sa.and_(
+                        *[
+                            sa.column(column) == table,
+                            sa.column("schemaname") == schema,
+                        ]
+                    )
+                )
+                .with_only_columns([sa.func.COUNT()])
+                .order_by(None)
+            ).scalar()
+            > 0
+        )
