@@ -9,6 +9,7 @@ from pgsync.exc import (
     NodeAttributeError,
     TableNotInNodeError,
 )
+from pgsync.settings import NTHREADS_POLLDB
 from pgsync.sync import Sync
 
 from .helpers.utils import assert_resync_empty, noop, search
@@ -216,6 +217,8 @@ class TestRoot(object):
                 "isbn",
                 "publisher_id",
                 "title",
+                "buyer_id",
+                "seller_id",
             ]
         )
 
@@ -230,6 +233,8 @@ class TestRoot(object):
                 "isbn",
                 "publisher_id",
                 "title",
+                "buyer_id",
+                "seller_id",
             ]
         )
         assert_resync_empty(sync, nodes)
@@ -464,7 +469,7 @@ class TestRoot(object):
                             "pgsync.sync.Sync.status",
                             side_effect=noop,
                         ):
-                            sync.receive()
+                            sync.receive(NTHREADS_POLLDB)
                             sync.es.refresh("testdb")
 
         docs = search(sync.es, "testdb")
@@ -609,7 +614,7 @@ class TestRoot(object):
                             "pgsync.sync.Sync.status",
                             side_effect=noop,
                         ):
-                            sync.receive()
+                            sync.receive(NTHREADS_POLLDB)
                             sync.es.refresh("testdb")
 
         docs = search(sync.es, "testdb")
@@ -668,7 +673,7 @@ class TestRoot(object):
                             "pgsync.sync.Sync.status",
                             side_effect=noop,
                         ):
-                            sync.receive()
+                            sync.receive(NTHREADS_POLLDB)
                             sync.es.refresh("testdb")
 
         docs = search(sync.es, "testdb")
