@@ -13,6 +13,7 @@ from pgsync.exc import (
     RelationshipVariantError,
 )
 from pgsync.node import Tree
+from pgsync.settings import NTHREADS_POLLDB
 from pgsync.sync import Sync
 
 from .helpers.utils import assert_resync_empty, noop, search
@@ -317,7 +318,7 @@ class TestParentSingleChildFkOnParent(object):
         assert_resync_empty(sync, nodes)
 
     def test_null_label(self, sync, data):
-        """null label should revert back to the table name"""
+        """Null label should revert back to the table name."""
         nodes = {
             "table": "book",
             "columns": ["isbn", "title", "description"],
@@ -459,6 +460,8 @@ class TestParentSingleChildFkOnParent(object):
             "isbn": "ghi",
             "publisher": {"id": 3, "name": "Hop Bunny publishing"},
             "publisher_id": 3,
+            "seller_id": None,
+            "buyer_id": None,
             "title": "The Rabbit Club",
         }
         assert_resync_empty(sync, nodes)
@@ -573,9 +576,7 @@ class TestParentSingleChildFkOnParent(object):
     def test_update_primary_key_non_concurrent(
         self, data, book_cls, publisher_cls, engine
     ):
-        """
-        Test sync updates primary_key and then sync in non-concurrent mode.
-        """
+        """Test sync updates primary_key then sync in non-concurrent mode."""
         document = {
             "index": "testdb",
             "nodes": {
@@ -753,7 +754,7 @@ class TestParentSingleChildFkOnParent(object):
                             "pgsync.sync.Sync.status",
                             side_effect=noop,
                         ):
-                            sync.receive()
+                            sync.receive(NTHREADS_POLLDB)
                             sync.es.refresh("testdb")
 
         docs = search(sync.es, "testdb")
@@ -1045,7 +1046,7 @@ class TestParentSingleChildFkOnParent(object):
                             "pgsync.sync.Sync.status",
                             side_effect=noop,
                         ):
-                            sync.receive()
+                            sync.receive(NTHREADS_POLLDB)
                             sync.es.refresh("testdb")
 
         docs = search(sync.es, "testdb")
@@ -1163,7 +1164,7 @@ class TestParentSingleChildFkOnParent(object):
                             "pgsync.sync.Sync.status",
                             side_effect=noop,
                         ):
-                            sync.receive()
+                            sync.receive(NTHREADS_POLLDB)
                             sync.es.refresh("testdb")
 
         docs = search(sync.es, "testdb")
